==> nateon-1.0.1.192.tar.bz2: nateon-1.0/nateon/dialog/inputbox.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef INPUTBOX_H
#define INPUTBOX_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>
#include <qvariant.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLineEdit;
class QPushButton;
class QLineEdit;

class InputBox : public QDialog
{
Q_OBJECT

public:
    InputBox( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~InputBox();

    void setLineEdit(QString sLine) { lineEdit1->setText(sLine); };

protected:
    QVBoxLayout* InputBoxLayout;
    QVBoxLayout* layout2;
    QHBoxLayout* Layout1;
    QSpacerItem* Horizontal_Spacing2;

protected slots:
    virtual void languageChange();
    void accept();

private:
    QLineEdit* lineEdit1;
    QPushButton* buttonOk;
    QPushButton* buttonCancel;
    QPixmap image0;

signals:
	void returnValue(QString sValue);

};

#endif // INPUTBOX_H

==> nateon-1.0.1.275.tar.bz2: nateon-1.0/nateon/dialog/inputbox.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef INPUTBOX_H
#define INPUTBOX_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>
#include <qvariant.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLineEdit;
class QPushButton;
class QLineEdit;

class InputBox : public QDialog {
    Q_OBJECT

public:
    InputBox( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~InputBox();

    void setLineEdit(QString sLine) {
        lineEdit1->setText(sLine);
    };

protected:
    QVBoxLayout* InputBoxLayout;
    QVBoxLayout* layout2;
    QHBoxLayout* Layout1;
    QSpacerItem* Horizontal_Spacing2;

protected slots:
    virtual void languageChange();
    void accept();

private:
    QLineEdit* lineEdit1;
    QPushButton* buttonOk;
    QPushButton* buttonCancel;
    QPixmap image0;

signals:
    void returnValue(QString sValue);

};

#endif // INPUTBOX_H
